@@ -1,24 +1,25 @@
-# A self-managing collection of objects.
+# A self-managing collection of objects.  See
+# Reflex::Role::Collectible for the other side of the
+# Collectible/Collection contract.
+
 package Reflex::Collection;
 BEGIN {
-  $Reflex::Collection::VERSION = '0.011';
+  $Reflex::Collection::VERSION = '0.050';
 }
 use Moose;
 use Reflex::Callbacks qw(cb_method);
 
-extends 'Reflex::Object';
-
-# TODO - Validate that collected objects satsify a complementary role.
+extends 'Reflex::Base';
 
 has objects => (
 	is      => 'rw',
-	isa     => 'HashRef[Reflex::Object]',
+	isa     => 'HashRef[Reflex::Collectible]',
 	default => sub { {} },
 );
 
 sub remember {
 	my ($self, $object) = @_;
-	$self->observe($object, stopped => cb_method($self, "cb_forget"));
+	$self->watch($object, stopped => cb_method($self, "cb_forget"));
 	$self->objects()->{$object} = $object;
 }
 
@@ -38,11 +39,11 @@ __END__
 
 =head1 NAME
 
-Reflex::Collection - Autmatically manage a collection of Reflex objects
+Reflex::Collection - Autmatically manage a collection of collectible objects
 
 =head1 VERSION
 
-version 0.011
+version 0.050
 
 =head1 SYNOPSIS
 
@@ -74,10 +75,10 @@ version 0.011
 
 =head1 DESCRIPTION
 
-Some object manage collections of other objects.  For example, network
-servers must track objects that represent client connections.  If not,
-those objects would go out of scope, destruct, and disconnect their
-clients.
+Some object manage collections of collectible objects---ones that
+consume Reflex::Role::Collectible.  For example, network servers must
+track objects that represent client connections.  If not, those
+objects would go out of scope, destruct, and disconnect their clients.
 
 Reflex::Collection is a generic object collection manager.  It exposes
 remember() and forget(), which may be mapped to other methods using
@@ -88,6 +89,14 @@ will automatically forget() objects that emit "stopped" events,
 triggering their destruction if nothing else refers to them.  This
 eliminates a large amount of repetitive work.
 
+Reflex::Role::Collectible provides a stopped() method that emits the
+"stopped" event.  Calling C<<$self->stopped()>> in the collectible
+class is sufficient to trigger the proper cleanup.
+
+TODO - Reflex::Collection is an excellent place to manage pools of
+objects.  Provide a callback interface for pulling new objects as
+needed.
+
 =head2 new
 
 Create a new Reflex::Collection.  It takes no parameters.
